@@ -1,7 +1,7 @@
 package Getopt::Long::Util;
 
-our $DATE = '2015-06-11'; # DATE
-our $VERSION = '0.83'; # VERSION
+our $DATE = '2016-01-08'; # DATE
+our $VERSION = '0.84'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,11 +22,18 @@ $SPEC{parse_getopt_long_opt_spec} = {
     summary => 'Parse a single Getopt::Long option specification',
     description => <<'_',
 
-Will produce a hash with some keys: `opts` (array of option names, in the order
-specified in the opt spec), `type` (string, type name), `desttype` (either '',
-or '@' or '%'), `is_neg` (true for `--opt!`), `is_inc` (true for `--opt+`),
-`min_vals` (int, usually 0 or 1), `max_vals` (int, usually 0 or 1 except for
-option that requires multiple values),
+Will produce a hash with some keys:
+
+* `is_arg` (if true, then option specification is the special `<>` for argument
+  callback)
+* `opts` (array of option names, in the order specified in the opt spec)
+* `type` (string, type name)
+* `desttype` (either '', or '@' or '%'),
+* `is_neg` (true for `--opt!`)
+* `is_inc` (true for `--opt+`)
+* `min_vals` (int, usually 0 or 1)
+* `max_vals` (int, usually 0 or 1 except for option that requires multiple
+  values)
 
 Will return undef if it can't parse the string.
 
@@ -57,6 +64,8 @@ _
 # BEGIN_BLOCK: parse_getopt_long_opt_spec
 sub parse_getopt_long_opt_spec {
     my $optspec = shift;
+    return {is_arg=>1, dash_prefix=>'', opts=>[]}
+        if $optspec eq '<>';
     $optspec =~ qr/\A
                (?P<dash_prefix>-{0,2})
                (?P<name>[A-Za-z0-9_][A-Za-z0-9_-]*)
@@ -146,6 +155,8 @@ sub humanize_getopt_long_opt_spec {
     my $parse = parse_getopt_long_opt_spec($optspec)
         or die "Can't parse opt spec $optspec";
 
+    return "argument" if $parse->{is_arg};
+
     my $res = '';
     my $i = 0;
     for (@{ $parse->{opts} }) {
@@ -286,7 +297,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.83 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2015-06-11.
+This document describes version 0.84 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-01-08.
 
 =head1 SEE ALSO
 
@@ -323,6 +334,8 @@ something like C<use Getopt::Long>;
 
 =back
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -364,6 +377,8 @@ C<debug!> into, respectively, C<--help, -h, -?> or C<--foo=s> or C<--(no)debug>.
 Will die if can't parse the string. The output is suitable for including in
 help/usage text.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -381,16 +396,50 @@ Parse a single Getopt::Long option specification.
 
 Examples:
 
- parse_getopt_long_opt_spec("help|h|?"); # -> { dash_prefix => "", opts => ["help", "h", "?"] }
- parse_getopt_long_opt_spec("--foo=s"); # -> { dash_prefix => "--", desttype => "", opts => ["foo"], type => "s" }
-Will produce a hash with some keys: C<opts> (array of option names, in the order
-specified in the opt spec), C<type> (string, type name), C<desttype> (either '',
-or '@' or '%'), C<is_neg> (true for C<--opt!>), C<is_inc> (true for C<--opt+>),
-C<min_vals> (int, usually 0 or 1), C<max_vals> (int, usually 0 or 1 except for
-option that requires multiple values),
+=over
+
+=item * Example #1:
+
+ parse_getopt_long_opt_spec( optspec => "help|h|?"); # -> { dash_prefix => "", opts => ["help", "h", "?"] }
+
+=item * Example #2:
+
+ parse_getopt_long_opt_spec( optspec => "--foo=s");
+
+Result:
+
+ { dash_prefix => "--", desttype => "", opts => ["foo"], type => "s" }
+
+=back
+
+Will produce a hash with some keys:
+
+=over
+
+=item * C<is_arg> (if true, then option specification is the special C<< E<lt>E<gt> >> for argument
+callback)
+
+=item * C<opts> (array of option names, in the order specified in the opt spec)
+
+=item * C<type> (string, type name)
+
+=item * C<desttype> (either '', or '@' or '%'),
+
+=item * C<is_neg> (true for C<--opt!>)
+
+=item * C<is_inc> (true for C<--opt+>)
+
+=item * C<min_vals> (int, usually 0 or 1)
+
+=item * C<max_vals> (int, usually 0 or 1 except for option that requires multiple
+values)
+
+=back
 
 Will return undef if it can't parse the string.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -423,7 +472,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
